@@ -118,3 +118,63 @@ async def test_database_isolation__2(aidbox_client, safe_db):
 
     patients = await aidbox_client.resources("Patient").fetch_all()
     assert len(patients) == 4
+
+
+@pytest.mark.asyncio()
+async def test_database_isolation_with_history_in_name__1(aidbox_client, safe_db):
+    resources = await aidbox_client.resources("FamilyMemberHistory").fetch_all()
+    assert len(resources) == 0
+
+    resource = aidbox_client.resource(
+        "FamilyMemberHistory",
+        status="completed",
+        patient={
+            "identifier": {"system": "http://example.org/test-patients", "value": "test-patient-1"}
+        },
+        relationship={
+            "coding": [
+                {"system": "http://terminology.hl7.org/CodeSystem/v3-RoleCode", "code": "FTH"}
+            ]
+        },
+    )
+    await resource.save()
+
+    resources = await aidbox_client.resources("FamilyMemberHistory").fetch_all()
+    assert len(resources) == 1
+
+
+@pytest.mark.asyncio()
+async def test_database_isolation_with_history_in_name__2(aidbox_client, safe_db):
+    resources = await aidbox_client.resources("FamilyMemberHistory").fetch_all()
+    assert len(resources) == 0
+
+    resource1 = aidbox_client.resource(
+        "FamilyMemberHistory",
+        status="completed",
+        patient={
+            "identifier": {"system": "http://example.org/test-patients", "value": "test-patient-1"}
+        },
+        relationship={
+            "coding": [
+                {"system": "http://terminology.hl7.org/CodeSystem/v3-RoleCode", "code": "FTH"}
+            ]
+        },
+    )
+    await resource1.save()
+
+    resource2 = aidbox_client.resource(
+        "FamilyMemberHistory",
+        status="completed",
+        patient={
+            "identifier": {"system": "http://example.org/test-patients", "value": "test-patient-2"}
+        },
+        relationship={
+            "coding": [
+                {"system": "http://terminology.hl7.org/CodeSystem/v3-RoleCode", "code": "MTH"}
+            ]
+        },
+    )
+    await resource2.save()
+
+    resources = await aidbox_client.resources("FamilyMemberHistory").fetch_all()
+    assert len(resources) == 2
